<?php
namespace CiviCrmFieldMigrate\lib;

class FieldParser {
  public $fields = array();
  public $file = "";
  private static $_fieldRegExp = '/custom[_\-]\d+/';
  public static $siteFields;
  public static $siteTables;

  function __construct($file, $site_fields) {
    $this->file = $file;
    if(empty(self::$siteFields)) {
      self::$siteFields = array();
      // We're using a static field here because there will only be one version of the data.
      // It seems silly to have a copy of it for each instance of this class.

      // We want to make a flat list of fields and just move the table name into field values.
      array_walk($site_fields, function($fields, $table_name){
        foreach($fields as $fid => &$field) {
          $field['table_name'] = $table_name;
        }
        // Merge this table's fields into the whole custom fields list.
        FieldParser::$siteFields = FieldParser::$siteFields + $fields;

        // Grab the first field form this table's info so we can get the table's ID.
        $table_info_field = reset($fields);
        FieldParser::$siteTables[$table_info_field['custom_group_id']] = $table_name;
      });
    }

    $test = 'ss';
  }

  function parseFields(&$errors) {
    if(!is_writable($this->file)) {
      // set and error and return null.
      $errors[] = 'File is not writable: ' . $this->file . '.';
      return false;
    }

    $contents = file_get_contents($this->file);
    $fields = array();

    // Get all instances of "custom_xxx".
    preg_match_all(self::$_fieldRegExp, $contents, $fields);
    // Do we have matches? Iterate over them and standardize the format to custom_xxx.
    if(!empty($fields[0])) {
      // Remove any forms of "custom_" or "custom-". We want just the field's ID.
      array_walk($fields[0], function(&$field, $index) use(&$errors) {
        $field = str_ireplace('custom-', '', $field);
        $field = str_ireplace('custom_', '', $field);
        if(!is_numeric($field)) {
          $errors[] = 'Unable to retrieve the numeric field ID from: ' . $field;
        }
        else {
          $field = intval($field);
        }
      });

      $this->fields = array_values(array_unique($fields[0]));
    }

    // Get all instances of: "field_column_name_xxx" or "field-column-name-xxx".
    foreach(self::$siteFields as $id => $field) {
      $pattern = '/' . str_replace('_', '[\-_]+', $field['column_name']) . '/i';
      if(preg_match($pattern, $contents) === 1) {
        // The file contains this field, add it to the $fields.
        $this->fields[] = $id;
      }
    }
    $test = 'ss';
  }
}
